summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--editor/dependency_editor.cpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/editor/dependency_editor.cpp b/editor/dependency_editor.cpp
index f5a60f2553..f559eb6cb2 100644
--- a/editor/dependency_editor.cpp
+++ b/editor/dependency_editor.cpp
@@ -496,11 +496,15 @@ void DependencyRemoveDialog::ok_pressed() {
res->set_path("");
}
// If the file we are deleting is the main scene, clear its definition.
if (files_to_delete[i] == ProjectSettings::get_singleton()->get("application/run/main_scene")) {
ProjectSettings::get_singleton()->set("application/run/main_scene", "");
}
+ if (files_to_delete[i] == ProjectSettings::get_singleton()->get("rendering/environment/default_environment")) {
+ ProjectSettings::get_singleton()->set("rendering/environment/default_environment", "");
+ }
+
String path = OS::get_singleton()->get_resource_dir() + files_to_delete[i].replace_first("res://", "/");
print_verbose("Moving to trash: " + path);
Error err = OS::get_singleton()->move_to_trash(path);
@@ -496,11 +496,15 @@ void DependencyRemoveDialog::ok_pressed() {
res->set_path("");
}
- // If the file we are deleting is the main scene, clear its definition.
+ // If the file we are deleting is the main scene or default environment, clear its definition.
if (files_to_delete[i] == ProjectSettings::get_singleton()->get("application/run/main_scene")) {
ProjectSettings::get_singleton()->set("application/run/main_scene", "");